# Directory for npm

Whenever a new version of the JS is ready to publish:
* copy from parent directory
* update the version in package.json
* run ./publish.sh
* update the version number in gatenlp/serialization/default.py: JS_GATENLP
